@@ -2,6 +2,7 @@
 
 import numpy as np
 import matplotlib.pyplot as plt
+import wuml
 
 class histograms:
 	def __init__(self, x, num_bins=10, title='', fontsize=12, facecolor='blue', α=0.5, 
@@ -9,6 +10,7 @@ class histograms:
 			path=None, subplot=None, ylogScale=False, show=True, normalize=False, 
 			title_font=12, xfont=12, yfont=12, figsize=None):
 
+		x = wuml.ensure_numpy(x)
 		self.title_font = title_font
 		self.xfont = xfont
 		self.yfont = yfont
@@ -26,7 +28,7 @@ class histograms:
 			normalize 	: Show the probability instead of count
 			show		: Calls the show function at the end
 		'''
-
+		x = wuml.ensure_numpy(x)
 		if subplot is not None: plt.subplot(subplot)
 
 
@@ -37,6 +39,7 @@ class histograms:
 		plt.xlabel(xlabel, fontsize=fontsize)
 		plt.ylabel(ylabel, fontsize=fontsize)
 		plt.title(title, fontsize=fontsize)
+
 		n, bins, patches = plt.hist(x, num_bins, facecolor=facecolor, alpha=α, density=normalize)
 		if ylogScale: plt.yscale('log', nonpositive='clip')
 		plt.tight_layout()
